summaryrefslogtreecommitdiffstats
path: root/src/usr/pnor/spnorrp.C
diff options
context:
space:
mode:
authorNick Bofferding <bofferdn@us.ibm.com>2017-04-21 12:34:01 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-04-28 16:28:57 -0400
commit65933dc2985b91be71ac35a6df2786f0e43ab779 (patch)
treedb50c52908c9bd3628d1aa6182e1981d6f6130b2 /src/usr/pnor/spnorrp.C
parent78b9f5fc8fdd8aa99796729902150eae0f7829b5 (diff)
downloadtalos-hostboot-65933dc2985b91be71ac35a6df2786f0e43ab779.tar.gz
talos-hostboot-65933dc2985b91be71ac35a6df2786f0e43ab779.zip
Split ATTR_SECURITY_MODE into FSP/HB specific attributes
Change-Id: Ib4eed5cb069b4cef02fefcc398e27a51d0b287f6 RTC: 170650 CMVC-Coreq: 1022371 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39552 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Stephen M. Cprek <smcprek@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Michael Baiocchi <mbaiocch@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/usr/pnor/spnorrp.C')
-rw-r--r--src/usr/pnor/spnorrp.C8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/usr/pnor/spnorrp.C b/src/usr/pnor/spnorrp.C
index 496ebabe9..f9d286da0 100644
--- a/src/usr/pnor/spnorrp.C
+++ b/src/usr/pnor/spnorrp.C
@@ -781,11 +781,11 @@ void SPnorRP::processLabOverride(
TARGETING::Target* pSys = nullptr;
TARGETING::targetService().getTopLevelTarget(pSys);
assert(pSys != nullptr,"System target was nullptr.");
- // ATTR_SECURITY_MODE attribute values are inverted with respect to the lab
- // override flag for the same logical meaning
- TARGETING::ATTR_SECURITY_MODE_type securityMode =
+ // ATTR_HB_SECURITY_MODE attribute values are inverted with respect to the
+ // lab override flag for the same logical meaning
+ TARGETING::ATTR_HB_SECURITY_MODE_type securityMode =
!(i_flags.hw_lab_override);
- pSys->setAttr<TARGETING::ATTR_SECURITY_MODE>(securityMode);
+ pSys->setAttr<TARGETING::ATTR_HB_SECURITY_MODE>(securityMode);
TRACFCOMP(g_trac_pnor,INFO_MRK "Set lab security override policy to %s.",
securityMode ? "*NO* override" : "override if requested");
}
OpenPOWER on IntegriCloud